aboutsummaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/private/AppFramework/Middleware/Security/SecurityMiddleware.php6
-rw-r--r--lib/private/Authentication/Listeners/UserDeletedFilesCleanupListener.php2
-rw-r--r--lib/private/Avatar/AvatarManager.php2
-rw-r--r--lib/private/Files/Node/Root.php2
-rw-r--r--lib/private/Server.php2
-rw-r--r--lib/private/Setup.php15
-rw-r--r--lib/private/Setup/AbstractDatabase.php4
-rw-r--r--lib/private/Setup/MySQL.php2
-rw-r--r--lib/private/Setup/OCI.php6
-rw-r--r--lib/private/Setup/PostgreSQL.php2
-rw-r--r--lib/private/Share20/Manager.php4
-rw-r--r--lib/private/Support/Subscription/Registry.php2
-rw-r--r--lib/private/User/Manager.php14
-rw-r--r--lib/private/User/Session.php2
-rw-r--r--lib/private/legacy/OC_User.php2
-rw-r--r--lib/private/legacy/OC_Util.php4
16 files changed, 36 insertions, 35 deletions
diff --git a/lib/private/AppFramework/Middleware/Security/SecurityMiddleware.php b/lib/private/AppFramework/Middleware/Security/SecurityMiddleware.php
index a97876fd9ab..386075bd968 100644
--- a/lib/private/AppFramework/Middleware/Security/SecurityMiddleware.php
+++ b/lib/private/AppFramework/Middleware/Security/SecurityMiddleware.php
@@ -180,20 +180,20 @@ class SecurityMiddleware extends Middleware {
}
}
if (!$authorized) {
- throw new NotAdminException($this->l10n->t('Logged in user must be an admin, a sub admin or gotten special right to access this setting'));
+ throw new NotAdminException($this->l10n->t('Logged in account must be an admin, a sub admin or gotten special right to access this setting'));
}
}
if ($this->hasAnnotationOrAttribute($reflectionMethod, 'SubAdminRequired', SubAdminRequired::class)
&& !$this->isSubAdmin
&& !$this->isAdminUser
&& !$authorized) {
- throw new NotAdminException($this->l10n->t('Logged in user must be an admin or sub admin'));
+ throw new NotAdminException($this->l10n->t('Logged in account must be an admin or sub admin'));
}
if (!$this->hasAnnotationOrAttribute($reflectionMethod, 'SubAdminRequired', SubAdminRequired::class)
&& !$this->hasAnnotationOrAttribute($reflectionMethod, 'NoAdminRequired', NoAdminRequired::class)
&& !$this->isAdminUser
&& !$authorized) {
- throw new NotAdminException($this->l10n->t('Logged in user must be an admin'));
+ throw new NotAdminException($this->l10n->t('Logged in account must be an admin'));
}
}
diff --git a/lib/private/Authentication/Listeners/UserDeletedFilesCleanupListener.php b/lib/private/Authentication/Listeners/UserDeletedFilesCleanupListener.php
index c1075c0901e..a29a73ad8ad 100644
--- a/lib/private/Authentication/Listeners/UserDeletedFilesCleanupListener.php
+++ b/lib/private/Authentication/Listeners/UserDeletedFilesCleanupListener.php
@@ -56,7 +56,7 @@ class UserDeletedFilesCleanupListener implements IEventListener {
$userHome = $this->mountProviderCollection->getHomeMountForUser($event->getUser());
$storage = $userHome->getStorage();
if (!$storage) {
- throw new \Exception("User has no home storage");
+ throw new \Exception("Account has no home storage");
}
// remove all wrappers, so we do the delete directly on the home storage bypassing any wrapper
diff --git a/lib/private/Avatar/AvatarManager.php b/lib/private/Avatar/AvatarManager.php
index 1e137fa8715..e88feb37ecd 100644
--- a/lib/private/Avatar/AvatarManager.php
+++ b/lib/private/Avatar/AvatarManager.php
@@ -138,7 +138,7 @@ class AvatarManager implements IAvatarManager {
} catch (NotPermittedException | StorageNotAvailableException $e) {
$this->logger->error("Unable to delete user avatars for $userId. gnoring avatar deletion");
} catch (NoUserException $e) {
- $this->logger->debug("User $userId not found. gnoring avatar deletion");
+ $this->logger->debug("Account $userId not found. Ignoring avatar deletion");
}
$this->config->deleteUserValue($userId, 'avatar', 'generated');
}
diff --git a/lib/private/Files/Node/Root.php b/lib/private/Files/Node/Root.php
index ee344f9be8b..9bfb610199b 100644
--- a/lib/private/Files/Node/Root.php
+++ b/lib/private/Files/Node/Root.php
@@ -383,7 +383,7 @@ class Root extends Folder implements IRootFolder {
try {
$folder = $this->get('/' . $userId . '/files');
if (!$folder instanceof \OCP\Files\Folder) {
- throw new \Exception("User folder for $userId exists as a file");
+ throw new \Exception("Account folder for \"$userId\" exists as a file");
}
} catch (NotFoundException $e) {
if (!$this->nodeExists('/' . $userId)) {
diff --git a/lib/private/Server.php b/lib/private/Server.php
index 0ff8e6fb717..8de4fa7d5ca 100644
--- a/lib/private/Server.php
+++ b/lib/private/Server.php
@@ -1155,7 +1155,7 @@ class Server extends ServerContainer implements IServerContainer {
$userDisplayName = $manager->getDisplayName($id);
if ($userDisplayName === null) {
$l = $c->get(IFactory::class)->get('core');
- return $l->t('Unknown user');
+ return $l->t('Unknown account');
}
return $userDisplayName;
});
diff --git a/lib/private/Setup/AbstractDatabase.php b/lib/private/Setup/AbstractDatabase.php
index 82c00cb271a..ef35ecef919 100644
--- a/lib/private/Setup/AbstractDatabase.php
+++ b/lib/private/Setup/AbstractDatabase.php
@@ -71,9 +71,9 @@ abstract class AbstractDatabase {
public function validate($config) {
$errors = [];
if (empty($config['dbuser']) && empty($config['dbname'])) {
- $errors[] = $this->trans->t("Enter the database username and name for %s", [$this->dbprettyname]);
+ $errors[] = $this->trans->t("Enter the database Login and name for %s", [$this->dbprettyname]);
} elseif (empty($config['dbuser'])) {
- $errors[] = $this->trans->t("Enter the database username for %s", [$this->dbprettyname]);
+ $errors[] = $this->trans->t("Enter the database Login for %s", [$this->dbprettyname]);
} elseif (empty($config['dbname'])) {
$errors[] = $this->trans->t("Enter the database name for %s", [$this->dbprettyname]);
}
diff --git a/lib/private/Setup/MySQL.php b/lib/private/Setup/MySQL.php
index 0d672f324eb..29d0651cc67 100644
--- a/lib/private/Setup/MySQL.php
+++ b/lib/private/Setup/MySQL.php
@@ -73,7 +73,7 @@ class MySQL extends AbstractDatabase {
$this->logger->error($e->getMessage(), [
'exception' => $e,
]);
- throw new \OC\DatabaseSetupException($this->trans->t('MySQL username and/or password not valid'),
+ throw new \OC\DatabaseSetupException($this->trans->t('MySQL Login and/or password not valid'),
$this->trans->t('You need to enter details of an existing account.'), 0, $e);
}
}
diff --git a/lib/private/Setup/OCI.php b/lib/private/Setup/OCI.php
index 477561bbe2a..8c5fa333f70 100644
--- a/lib/private/Setup/OCI.php
+++ b/lib/private/Setup/OCI.php
@@ -53,9 +53,9 @@ class OCI extends AbstractDatabase {
public function validate($config) {
$errors = [];
if (empty($config['dbuser']) && empty($config['dbname'])) {
- $errors[] = $this->trans->t("Enter the database username and name for %s", [$this->dbprettyname]);
+ $errors[] = $this->trans->t("Enter the database Login and name for %s", [$this->dbprettyname]);
} elseif (empty($config['dbuser'])) {
- $errors[] = $this->trans->t("Enter the database username for %s", [$this->dbprettyname]);
+ $errors[] = $this->trans->t("Enter the database Login for %s", [$this->dbprettyname]);
} elseif (empty($config['dbname'])) {
$errors[] = $this->trans->t("Enter the database name for %s", [$this->dbprettyname]);
}
@@ -75,7 +75,7 @@ class OCI extends AbstractDatabase {
. ' NLS_LANG=' . getenv('NLS_LANG')
. ' tnsnames.ora is ' . (is_readable(getenv('ORACLE_HOME') . '/network/admin/tnsnames.ora') ? '' : 'not ') . 'readable', 0, $e);
}
- throw new \OC\DatabaseSetupException($this->trans->t('Oracle username and/or password not valid'),
+ throw new \OC\DatabaseSetupException($this->trans->t('Oracle Login and/or password not valid'),
'Check environment: ORACLE_HOME=' . getenv('ORACLE_HOME')
. ' ORACLE_SID=' . getenv('ORACLE_SID')
. ' LD_LIBRARY_PATH=' . getenv('LD_LIBRARY_PATH')
diff --git a/lib/private/Setup/PostgreSQL.php b/lib/private/Setup/PostgreSQL.php
index 490cbba69a9..84a978eab20 100644
--- a/lib/private/Setup/PostgreSQL.php
+++ b/lib/private/Setup/PostgreSQL.php
@@ -114,7 +114,7 @@ class PostgreSQL extends AbstractDatabase {
$this->logger->error($e->getMessage(), [
'exception' => $e,
]);
- throw new \OC\DatabaseSetupException($this->trans->t('PostgreSQL username and/or password not valid'),
+ throw new \OC\DatabaseSetupException($this->trans->t('PostgreSQL Login and/or password not valid'),
$this->trans->t('You need to enter details of an existing account.'), 0, $e);
}
}
diff --git a/lib/private/Share20/Manager.php b/lib/private/Share20/Manager.php
index 3af74789602..40af8546818 100644
--- a/lib/private/Share20/Manager.php
+++ b/lib/private/Share20/Manager.php
@@ -578,7 +578,7 @@ class Manager implements IManager {
// Identical share already exists
if ($existingShare->getSharedWith() === $share->getSharedWith() && $existingShare->getShareType() === $share->getShareType()) {
- $message = $this->l->t('Sharing %s failed, because this item is already shared with user %s', [$share->getNode()->getName(), $share->getSharedWithDisplayName()]);
+ $message = $this->l->t('Sharing %s failed, because this item is already shared with the account %s', [$share->getNode()->getName(), $share->getSharedWithDisplayName()]);
throw new AlreadySharedException($message, $existingShare);
}
@@ -589,7 +589,7 @@ class Manager implements IManager {
$user = $this->userManager->get($share->getSharedWith());
if ($group->inGroup($user) && $existingShare->getShareOwner() !== $share->getShareOwner()) {
- $message = $this->l->t('Sharing %s failed, because this item is already shared with user %s', [$share->getNode()->getName(), $share->getSharedWithDisplayName()]);
+ $message = $this->l->t('Sharing %s failed, because this item is already shared with the account %s', [$share->getNode()->getName(), $share->getSharedWithDisplayName()]);
throw new AlreadySharedException($message, $existingShare);
}
}
diff --git a/lib/private/Support/Subscription/Registry.php b/lib/private/Support/Subscription/Registry.php
index 008cded5dd3..f313574f96b 100644
--- a/lib/private/Support/Subscription/Registry.php
+++ b/lib/private/Support/Subscription/Registry.php
@@ -239,7 +239,7 @@ class Registry implements IRegistry {
$notificationManager->notify($notification);
}
- $this->logger->warning('The user limit was reached and the new user was not created', ['app' => 'lib']);
+ $this->logger->warning('The account limit was reached and the new account was not created', ['app' => 'lib']);
}
protected function reIssue(): bool {
diff --git a/lib/private/User/Manager.php b/lib/private/User/Manager.php
index 705f5fbe66b..25a75078503 100644
--- a/lib/private/User/Manager.php
+++ b/lib/private/User/Manager.php
@@ -456,7 +456,7 @@ class Manager extends PublicEmitter implements IUserManager {
// Check if user already exists
if ($this->userExists($uid)) {
- throw new \InvalidArgumentException($l->t('The username is already being used'));
+ throw new \InvalidArgumentException($l->t('The Login is already being used'));
}
/** @deprecated 21.0.0 use BeforeUserCreatedEvent event with the IEventDispatcher instead */
@@ -464,7 +464,7 @@ class Manager extends PublicEmitter implements IUserManager {
$this->eventDispatcher->dispatchTyped(new BeforeUserCreatedEvent($uid, $password));
$state = $backend->createUser($uid, $password);
if ($state === false) {
- throw new \InvalidArgumentException($l->t('Could not create user'));
+ throw new \InvalidArgumentException($l->t('Could not create account'));
}
$user = $this->getUserObject($uid, $backend);
if ($user instanceof IUser) {
@@ -734,27 +734,27 @@ class Manager extends PublicEmitter implements IUserManager {
// Check the name for bad characters
// Allowed are: "a-z", "A-Z", "0-9", spaces and "_.@-'"
if (preg_match('/[^a-zA-Z0-9 _.@\-\']/', $uid)) {
- throw new \InvalidArgumentException($l->t('Only the following characters are allowed in a username:'
+ throw new \InvalidArgumentException($l->t('Only the following characters are allowed in an Login:'
. ' "a-z", "A-Z", "0-9", spaces and "_.@-\'"'));
}
// No empty username
if (trim($uid) === '') {
- throw new \InvalidArgumentException($l->t('A valid username must be provided'));
+ throw new \InvalidArgumentException($l->t('A valid Login must be provided'));
}
// No whitespace at the beginning or at the end
if (trim($uid) !== $uid) {
- throw new \InvalidArgumentException($l->t('Username contains whitespace at the beginning or at the end'));
+ throw new \InvalidArgumentException($l->t('Login contains whitespace at the beginning or at the end'));
}
// Username only consists of 1 or 2 dots (directory traversal)
if ($uid === '.' || $uid === '..') {
- throw new \InvalidArgumentException($l->t('Username must not consist of dots only'));
+ throw new \InvalidArgumentException($l->t('Login must not consist of dots only'));
}
if (!$this->verifyUid($uid, $checkDataDirectory)) {
- throw new \InvalidArgumentException($l->t('Username is invalid because files already exist for this user'));
+ throw new \InvalidArgumentException($l->t('Login is invalid because files already exist for this user'));
}
}
diff --git a/lib/private/User/Session.php b/lib/private/User/Session.php
index b7f29134379..ab6ec9f38d3 100644
--- a/lib/private/User/Session.php
+++ b/lib/private/User/Session.php
@@ -367,7 +367,7 @@ class Session implements IUserSession, Emitter {
if (!$user->isEnabled()) {
// disabled users can not log in
// injecting l10n does not work - there is a circular dependency between session and \OCP\L10N\IFactory
- $message = \OCP\Util::getL10N('lib')->t('User disabled');
+ $message = \OCP\Util::getL10N('lib')->t('Account disabled');
throw new LoginException($message);
}
diff --git a/lib/private/legacy/OC_User.php b/lib/private/legacy/OC_User.php
index d2dc2a2389f..cefdd0ad2ee 100644
--- a/lib/private/legacy/OC_User.php
+++ b/lib/private/legacy/OC_User.php
@@ -178,7 +178,7 @@ class OC_User {
$dispatcher = \OC::$server->get(IEventDispatcher::class);
if ($userSession->getUser() && !$userSession->getUser()->isEnabled()) {
- $message = \OC::$server->getL10N('lib')->t('User disabled');
+ $message = \OC::$server->getL10N('lib')->t('Account disabled');
throw new LoginException($message);
}
$userSession->setLoginName($uid);
diff --git a/lib/private/legacy/OC_Util.php b/lib/private/legacy/OC_Util.php
index c008ccd63ba..3b6d9b8baec 100644
--- a/lib/private/legacy/OC_Util.php
+++ b/lib/private/legacy/OC_Util.php
@@ -732,8 +732,8 @@ class OC_Util {
if ($perms[2] !== '0') {
$l = \OC::$server->getL10N('lib');
return [[
- 'error' => $l->t('Your data directory is readable by other users.'),
- 'hint' => $l->t('Please change the permissions to 0770 so that the directory cannot be listed by other users.'),
+ 'error' => $l->t('Your data directory is readable by other people.'),
+ 'hint' => $l->t('Please change the permissions to 0770 so that the directory cannot be listed by other people.'),
]];
}
}
diff --git a/lib/private/Setup.php b/lib/private/Setup.php
index 650dca97067..1e42fbfbeb5 100644
--- a/lib/private/Setup.php
+++ b/lib/private/Setup.php
@@ -265,7 +265,7 @@ class Setup {
$dbType = $options['dbtype'];
if (empty($options['adminlogin'])) {
- $error[] = $l->t('Set an admin username.');
+ $error[] = $l->t('Set an admin Login.');
}
if (empty($options['adminpass'])) {
$error[] = $l->t('Set an admin password.');
@@ -311,7 +311,7 @@ class Setup {
$dbType = 'sqlite3';
}
- //generate a random salt that is used to salt the local user passwords
+ //generate a random salt that is used to salt the local passwords
$salt = $this->random->generate(30);
// generate a secret
$secret = $this->random->generate(48);
@@ -345,7 +345,7 @@ class Setup {
return $error;
} catch (Exception $e) {
$error[] = [
- 'error' => 'Error while trying to create admin user: ' . $e->getMessage(),
+ 'error' => 'Error while trying to create admin account: ' . $e->getMessage(),
'exception' => $e,
'hint' => '',
];
@@ -365,13 +365,14 @@ class Setup {
return $error;
}
- $this->outputDebug($output, 'Create admin user');
- //create the user and group
+ $this->outputDebug($output, 'Create admin account');
+
+ // create the admin account and group
$user = null;
try {
$user = Server::get(IUserManager::class)->createUser($username, $password);
if (!$user) {
- $error[] = "User <$username> could not be created.";
+ $error[] = "Account <$username> could not be created.";
return $error;
}
} catch (Exception $exception) {
@@ -428,7 +429,7 @@ class Setup {
$userSession->login($username, $password);
$user = $userSession->getUser();
if (!$user) {
- $error[] = "No user found in session.";
+ $error[] = "No account found in session.";
return $error;
}
$userSession->createSessionToken($request, $user->getUID(), $username, $password);